#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base-compat-batteries
version:              0.14.1
visibility:           public
id:                   base-compat-batteries-0.14.1-98gIhJRSrDv1hR9usVPzbO
key:                  base-compat-batteries-0.14.1-98gIhJRSrDv1hR9usVPzbO
license:              MIT
copyright:
    (c) 2012-2018 Simon Hengel,
    (c) 2014-2018 João Cristóvão,
    (c) 2015-2018 Ryan Scott

maintainer:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:
    Simon Hengel <sol@typeful.net>,
    João Cristóvão <jmacristovao@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

synopsis:             base-compat with extra batteries
description:
    Provides functions available in later versions of @base@ to
    a wider range of compilers, without requiring you to use CPP
    pragmas in your code.

    This package provides the same API as the
    @<http://hackage.haskell.org/package/base-compat base-compat>@
    library, but depends on compatibility packages
    (such as @semigroups@) to offer a wider support window than
    @base-compat@, which has no dependencies. Most of the modules
    in this library have the same names as in @base-compat@
    to make it easier to switch between the two. There also exist
    versions of each module with the suffix @.Repl.Batteries@,
    which are distinct from anything in @base-compat@, to allow
    for easier use in GHCi.

    See
    @<https://github.com/haskell-compat/base-compat/blob/master/base-compat/README.markdown#dependencies here>@
    for a more comprehensive list of differences between
    @base-compat@ and @base-compat-batteries@.

category:             Compatibility
abi:                  e1dfaad2770fd0aa6988fedd83a764d4
exposed:              True
exposed-modules:
    Control.Concurrent.Compat Control.Concurrent.Compat.Repl.Batteries
    Control.Concurrent.MVar.Compat
    Control.Concurrent.MVar.Compat.Repl.Batteries
    Control.Exception.Compat Control.Exception.Compat.Repl.Batteries
    Control.Monad.Compat Control.Monad.Compat.Repl.Batteries
    Control.Monad.Fail.Compat Control.Monad.Fail.Compat.Repl.Batteries
    Control.Monad.IO.Class.Compat
    Control.Monad.IO.Class.Compat.Repl.Batteries
    Control.Monad.ST.Lazy.Unsafe.Compat
    Control.Monad.ST.Lazy.Unsafe.Compat.Repl.Batteries
    Control.Monad.ST.Unsafe.Compat
    Control.Monad.ST.Unsafe.Compat.Repl.Batteries
    Data.Bifoldable.Compat Data.Bifoldable.Compat.Repl.Batteries
    Data.Bifoldable1.Compat Data.Bifoldable1.Compat.Repl.Batteries
    Data.Bifunctor.Compat Data.Bifunctor.Compat.Repl.Batteries
    Data.Bitraversable.Compat Data.Bitraversable.Compat.Repl.Batteries
    Data.Bits.Compat Data.Bits.Compat.Repl.Batteries Data.Bool.Compat
    Data.Bool.Compat.Repl.Batteries Data.Complex.Compat
    Data.Complex.Compat.Repl.Batteries Data.Either.Compat
    Data.Either.Compat.Repl.Batteries Data.Foldable.Compat
    Data.Foldable.Compat.Repl.Batteries Data.Foldable1.Compat
    Data.Foldable1.Compat.Repl.Batteries Data.Function.Compat
    Data.Function.Compat.Repl.Batteries Data.Functor.Compat
    Data.Functor.Compat.Repl.Batteries Data.Functor.Compose.Compat
    Data.Functor.Compose.Compat.Repl.Batteries
    Data.Functor.Const.Compat Data.Functor.Const.Compat.Repl.Batteries
    Data.Functor.Contravariant.Compat
    Data.Functor.Contravariant.Compat.Repl.Batteries
    Data.Functor.Identity.Compat
    Data.Functor.Identity.Compat.Repl.Batteries
    Data.Functor.Product.Compat
    Data.Functor.Product.Compat.Repl.Batteries Data.Functor.Sum.Compat
    Data.Functor.Sum.Compat.Repl.Batteries Data.IORef.Compat
    Data.IORef.Compat.Repl.Batteries Data.List.Compat
    Data.List.Compat.Repl.Batteries Data.List.NonEmpty.Compat
    Data.List.NonEmpty.Compat.Repl.Batteries Data.Monoid.Compat
    Data.Monoid.Compat.Repl.Batteries Data.Proxy.Compat
    Data.Proxy.Compat.Repl.Batteries Data.Ratio.Compat
    Data.Ratio.Compat.Repl.Batteries Data.STRef.Compat
    Data.STRef.Compat.Repl.Batteries Data.Semigroup.Compat
    Data.Semigroup.Compat.Repl.Batteries Data.String.Compat
    Data.String.Compat.Repl.Batteries Data.Traversable.Compat
    Data.Traversable.Compat.Repl.Batteries Data.Tuple.Compat
    Data.Tuple.Compat.Repl.Batteries Data.Type.Coercion.Compat
    Data.Type.Coercion.Compat.Repl.Batteries Data.Type.Equality.Compat
    Data.Type.Equality.Compat.Repl.Batteries Data.Typeable.Compat
    Data.Typeable.Compat.Repl.Batteries Data.Version.Compat
    Data.Version.Compat.Repl.Batteries Data.Void.Compat
    Data.Void.Compat.Repl.Batteries Data.Word.Compat
    Data.Word.Compat.Repl.Batteries Debug.Trace.Compat
    Debug.Trace.Compat.Repl.Batteries Foreign.Compat
    Foreign.Compat.Repl.Batteries Foreign.ForeignPtr.Compat
    Foreign.ForeignPtr.Compat.Repl.Batteries
    Foreign.ForeignPtr.Safe.Compat
    Foreign.ForeignPtr.Safe.Compat.Repl.Batteries
    Foreign.ForeignPtr.Unsafe.Compat
    Foreign.ForeignPtr.Unsafe.Compat.Repl.Batteries
    Foreign.Marshal.Alloc.Compat
    Foreign.Marshal.Alloc.Compat.Repl.Batteries
    Foreign.Marshal.Array.Compat
    Foreign.Marshal.Array.Compat.Repl.Batteries Foreign.Marshal.Compat
    Foreign.Marshal.Compat.Repl.Batteries Foreign.Marshal.Safe.Compat
    Foreign.Marshal.Safe.Compat.Repl.Batteries
    Foreign.Marshal.Unsafe.Compat
    Foreign.Marshal.Unsafe.Compat.Repl.Batteries
    Foreign.Marshal.Utils.Compat
    Foreign.Marshal.Utils.Compat.Repl.Batteries Numeric.Compat
    Numeric.Compat.Repl.Batteries Numeric.Natural.Compat
    Numeric.Natural.Compat.Repl.Batteries Prelude.Compat
    Prelude.Compat.Repl.Batteries System.Environment.Compat
    System.Environment.Compat.Repl.Batteries System.Exit.Compat
    System.Exit.Compat.Repl.Batteries System.IO.Compat
    System.IO.Compat.Repl.Batteries System.IO.Error.Compat
    System.IO.Error.Compat.Repl.Batteries System.IO.Unsafe.Compat
    System.IO.Unsafe.Compat.Repl.Batteries Text.Read.Compat
    Text.Read.Compat.Repl.Batteries Text.Read.Lex.Compat
    Text.Read.Lex.Compat.Repl.Batteries Type.Reflection.Compat
    Type.Reflection.Compat.Repl.Batteries

import-dirs:          /usr/lib/ghc-9.6.6/site-local/base-compat-batteries-0.14.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/base-compat-batteries-0.14.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/base-compat-batteries-0.14.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base-compat-batteries
hs-libraries:         HSbase-compat-batteries-0.14.1-98gIhJRSrDv1hR9usVPzbO
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    ghc-prim-0.10.0

haddock-interfaces:
    /usr/share/doc/haskell-base-compat-batteries/html/base-compat-batteries.haddock

haddock-html:         /usr/share/doc/haskell-base-compat-batteries/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

